// C Source File
// Created 1/25/2004; 12.03.37

#ifndef _GRAPHICS_C_
#define _GRAPHICS_C_

#include "graphics.h"

void drawBoard(int size)
{
	int i;

	int x = BOARDOFFSET_X, 
			y = BOARDOFFSET_Y,
	    squarewidth = CELL_WIDTH;


	SetPlane(0);
	for (i=1; i<size; i++)
	{
		DrawLine(i*squarewidth+x, y, i*squarewidth+x, size*squarewidth+y, A_NORMAL);
		DrawLine(x, i*squarewidth+y, size*squarewidth+x, i*squarewidth+y, A_NORMAL);
	}
	
	SetPlane(0); DrawLine(0, 6, LCD_WIDTH-1, 6, A_NORMAL);
	SetPlane(1); DrawLine(0, 6, LCD_WIDTH-1, 6, A_NORMAL);
		
}

void XORsquare(int r, int c)
{
	int x = c*CELL_WIDTH+BOARDOFFSET_X;
	int y = r*CELL_WIDTH+BOARDOFFSET_Y;

	int i;

	SetPlane(0);
	for (i=1; i<CELL_WIDTH; i++)
	{
		DrawLine(x+1, y+i, x+CELL_WIDTH-1, y+i, A_XOR);
	}
}

void sendMessage(char *message)
{


	int i;
	
	for (i=0; i<6; i++) {
		SetPlane(0); DrawLine(0, i, LCD_WIDTH-1, i, A_REVERSE);
		SetPlane(1); DrawLine(0, i, LCD_WIDTH-1, i, A_REVERSE);
	}

	FontSetSys(F_4x6);		
	SetPlane(0); DrawStr(0, 0, message, A_NORMAL);
	SetPlane(1); DrawStr(0, 0, message, A_NORMAL);

}

void DrawGrayScreen(unsigned char* src1, unsigned char* src2)
{

    unsigned char* plane1;
    unsigned char* plane2;
    unsigned char* dest1;
    unsigned char* dest2;
    int            loop;
    
    //-----------------------------------------------
    // fetch start addresses of planes
    //-----------------------------------------------
    plane1 = GetPlane(0);
    plane2 = GetPlane(1);

    //-----------------------------------------------
    // due to the fact that the LCD size of the TI89
    // is internally the same than the LCD size of 
    // the TI92 we cannot directly copy the complete
    // contents of the layer1 and layer2 arrays into
    // the bitplanes, but we have to copy each line
    // separately taking the offsets at each line
    // into account
    //-----------------------------------------------

    dest1 = plane1;
    dest2 = plane2;

    //-----------------------------------------------
    // on the TI92 we have to clear both bitplanes
    // because the skipped parts will be visible
    //
    // additionally we have to add an initial offset
    // to the destination pointers
    //-----------------------------------------------
    if (!TI89) {
        //memset(plane1,0,LCD_SIZE);
        //memset(plane2,0,LCD_SIZE);

        //-------------------------------------------
        // setup the destination pointers taking the 
        // initial offset into account
        // (each line consists of 30 bytes on a TI92)
        //-------------------------------------------
        dest1 += ((128-100)*30)/2 + ((240-160)/8)/2;
        dest2 += ((128-100)*30)/2 + ((240-160)/8)/2;
    }

    //-----------------------------------------------
    // ... and now copy all lines from the data 
    // arrays to the bitplanes
    //-----------------------------------------------
    for (loop=0;loop<100;loop++,src1+=20,src2+=20,dest1+=30,dest2+=30) {
        memcpy(dest1,src1,20);
        memcpy(dest2,src2,20);
    }      
}



#endif